@@ -57,6 +57,7 @@ new KinesisStreamsToKinesisFirehoseToS3(scope: Construct, id: string, props: Kin
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
 |existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
 |createCloudWatchAlarms?|`boolean`|Whether to create recommended CloudWatch alarms|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
@@ -142,6 +143,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -152,6 +154,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
 
         :access: public
         :since: 1.68.0
@@ -164,6 +167,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
             existing_stream_obj=existing_stream_obj,
             kinesis_firehose_props=kinesis_firehose_props,
             kinesis_stream_props=kinesis_stream_props,
+            log_group_props=log_group_props,
         )
 
         jsii.create(KinesisStreamsToKinesisFirehoseToS3, self, [scope, id, props])
@@ -216,6 +220,7 @@ class KinesisStreamsToKinesisFirehoseToS3(
         "existing_stream_obj": "existingStreamObj",
         "kinesis_firehose_props": "kinesisFirehoseProps",
         "kinesis_stream_props": "kinesisStreamProps",
+        "log_group_props": "logGroupProps",
     },
 )
 class KinesisStreamsToKinesisFirehoseToS3Props:
@@ -228,6 +233,7 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_firehose_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
         """The properties for the KinesisStreamsToKinesisFirehoseToS3 class.
 
@@ -237,11 +243,14 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_firehose_props: Optional user provided props to override the default props. Default: - Default props are used
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         """
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_stream_props, dict):
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+        if isinstance(log_group_props, dict):
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         self._values: typing.Dict[str, typing.Any] = {}
         if bucket_props is not None:
             self._values["bucket_props"] = bucket_props
@@ -255,6 +264,8 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
             self._values["kinesis_firehose_props"] = kinesis_firehose_props
         if kinesis_stream_props is not None:
             self._values["kinesis_stream_props"] = kinesis_stream_props
+        if log_group_props is not None:
+            self._values["log_group_props"] = log_group_props
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
@@ -310,6 +321,15 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         result = self._values.get("kinesis_stream_props")
         return result
 
+    @builtins.property
+    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("log_group_props")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
